'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = GenericLink;

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _urlParse = require('url-parse');

var _urlParse2 = _interopRequireDefault(_urlParse);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function GenericLink(props) {
  var activeClassName = props.activeClassName,
      activeStyle = props.activeStyle,
      children = props.children,
      className = props.className,
      enforceA = props.enforceA,
      exact = props.exact,
      isActive = props.isActive,
      location = props.location,
      _onClick = props.onClick,
      onMouseDown = props.onMouseDown,
      openNewTab = props.openNewTab,
      replace = props.replace,
      routerLinkType = props.routerLinkType,
      strict = props.strict,
      to = props.to;
  /* Renders the link as <a> element if either opted explicitely, or the link
   * should open a new tab, or it is an anchor reference. */

  if (enforceA || openNewTab || to.startsWith('#')) {
    return _react2.default.createElement(
      'a',
      {
        className: className,
        href: to,
        onClick: _onClick,
        onMouseDown: onMouseDown,
        rel: openNewTab ? 'noopener noreferrer' : '',
        target: openNewTab ? '_blank' : ''
      },
      children
    );
  }

  /* Otherwise we render the link as React Router's Link or NavLink element. */
  return _react2.default.createElement(routerLinkType, {
    activeClassName: activeClassName,
    activeStyle: activeStyle,
    className: className,
    exact: exact,
    isActive: isActive,
    location: location,
    onClick: function onClick(e) {
      /* If a custom onClick(..) handler was provided we execute it. */
      if (_onClick) _onClick(e);

      /* If the URL leads to a different domain we make transition using JS,
       * preventing event processing by React Router. */
      var url = new _urlParse2.default(to);
      if (url.origin !== document.location.origin) {
        document.location = to;
        e.preventDefault();

        /* Scroll to the top-left corner of the page, just in case the link
         * references the same page we are already in. */
      } else window.scroll(0, 0);
    },
    onMouseDown: onMouseDown,
    replace: replace,
    strict: strict,
    to: to
  });
} /**
   * The GenericLink wraps around React Router's Link or NavLink component, to
   * automatically replace them by regular <a> elements when:
   * - The target reference points to another domain;
   * - User opts to open the reference in a new tab;
   * - User explicitely opts to use <a>.
   */

/* global document, window */

GenericLink.defaultProps = {
  activeClassName: null,
  activeStyle: null,
  children: null,
  className: null,
  enforceA: false,
  exact: false,
  isActive: null,
  location: null,
  onClick: null,
  onMouseDown: null,
  openNewTab: false,
  replace: false,
  strict: false,
  to: ''
};

GenericLink.propTypes = {
  activeClassName: _propTypes2.default.string,
  activeStyle: _propTypes2.default.string,
  children: _propTypes2.default.node,
  className: _propTypes2.default.string,
  enforceA: _propTypes2.default.bool,
  exact: _propTypes2.default.bool,
  isActive: _propTypes2.default.func,
  location: _propTypes2.default.shape(),
  onClick: _propTypes2.default.func,
  onMouseDown: _propTypes2.default.func,
  openNewTab: _propTypes2.default.bool,
  replace: _propTypes2.default.bool,
  routerLinkType: _propTypes2.default.element.isRequired,
  strict: _propTypes2.default.bool,
  to: _propTypes2.default.oneOfType([_propTypes2.default.object, _propTypes2.default.string])
};